@@ -12,6 +12,7 @@ pub mod approval_state;
 pub mod approvals;
 mod approve;
 pub mod awards;
+mod changes;
 mod create;
 pub mod discussions;
 mod edit;
@@ -20,6 +21,7 @@ mod merge;
 mod merge_request;
 mod merge_requests;
 pub mod notes;
+mod pipelines;
 mod rebase;
 mod resource_label_events;
 mod unapprove;
@@ -43,6 +45,12 @@ pub use self::merge::MergeMergeRequestBuilder;
 pub use self::merge_request::MergeRequest;
 pub use self::merge_request::MergeRequestBuilder;
 
+pub use self::pipelines::MergeRequestPipelines;
+pub use self::pipelines::MergeRequestPipelinesBuilder;
+
+pub use self::changes::MergeRequestChanges;
+pub use self::changes::MergeRequestChangesBuilder;
+
 pub use self::merge_requests::MergeRequestOrderBy;
 pub use self::merge_requests::MergeRequestScope;
 pub use self::merge_requests::MergeRequestSearchScope;
